/** @file
===========================================================================
MODULE          : WavHeaderData

DESCRIPTIONS    : Simple Storage class to store information about a WAV stream: adapted from LiveMedia examples

REVISION HISTORY: Version 1.0

COPYRIGHT       : (c)CSIR, Meraka Institute 2007 all rights reserved

RESTRICTIONS	: The information/data/code contained within this file is 
				  the property of CSIR, Meraka Institute and has been 
				  classified as PUBLIC.
===========================================================================
*/
#pragma once

#include <string>

// WAV Format codes
const int WAV_PCM  = 1;
const int WAV_PCMA = 6;
const int WAV_PCMU = 7;

class WavHeaderData
{
public:
	WavHeaderData(void);
	WavHeaderData(unsigned char audioFormat, unsigned char bitsPerSample, unsigned samplingFrequency, unsigned numChannels);

	~WavHeaderData(void);
	unsigned char AudioFormat() const { return m_audioFormat; }
	void AudioFormat(unsigned char val) { m_audioFormat = val; }
	unsigned char BitsPerSample() const { return m_bitsPerSample; }
	void BitsPerSample(unsigned char val) { m_bitsPerSample = val; }
	unsigned SamplingFrequency() const { return m_samplingFrequency; }
	void SamplingFrequency(unsigned val) 
	{ 
		m_samplingFrequency = val;
		// Also set sampling frequency
		m_playTimePerSample = 1e6/(double)m_samplingFrequency;
	}
	unsigned NumChannels() const { return m_numChannels; }
	void NumChannels(unsigned val) { m_numChannels = val; }
	double PlayTimePerSample() const { return m_playTimePerSample; }
	unsigned PreferredFrameSize();

	inline void ConvertToString(int nNumber)
	{
		itoa((int)nNumber, m_szBuffer, 10);
	}
	std::string GetFormatString()
	{
		ConvertToString(m_audioFormat);
		std::string sStr = "Audio Format: " + std::string(m_szBuffer) + "\r\n";
		ConvertToString(m_bitsPerSample);
		sStr += "Bits per sample: " + std::string(m_szBuffer) + "\r\n";
		ConvertToString(m_numChannels);
		sStr += "Number of channels: " + std::string(m_szBuffer) + "\r\n";
		ConvertToString(m_samplingFrequency);
		sStr += "Sampling frequency: " + std::string(m_szBuffer) + "\r\n";
		ConvertToString(PreferredFrameSize());
		sStr += "Preferred frame size: " + std::string(m_szBuffer) + "\r\n";
		return sStr;
	}
private:
	unsigned char m_audioFormat;
	unsigned char m_bitsPerSample;
	unsigned m_samplingFrequency;
	unsigned m_numChannels;
	//unsigned fWAVHeaderSize;
	double m_playTimePerSample;
	unsigned fPreferredFrameSize;

	char m_szBuffer[32];
};
