/** @file

MODULE				: YUV420toRGBConverter

TAG					: YUVRGBC

FILE NAME			: YUV420toRGBConverter.h

DESCRIPTION			: Colour convertions are required on the output of
					  all video codecs. For embedded applications only some
					  combinations of colour depths and inversions are required.
					  This class is the base class defining the minimum interface
					  and properties for all derived classes. 

REVISION HISTORY	:

COPYRIGHT			: (c)CSIR, Meraka Institute 2007 all rights reserved

RESTRICTIONS		: The information/data/code contained within this file is 
					  the property of CSIR, Meraka Institute and has been 
					  classified as PUBLIC.
===========================================================================
*/
#ifndef _YUV420TORGBCONVERTER_H
#define _YUV420TORGBCONVERTER_H

#pragma once

#ifdef _BUILD_FOR_SHORT
typedef short yuvType;
#else
typedef signed char yuvType ;
#endif

/*
===========================================================================
  Class definition.
===========================================================================
*/
class YUV420toRGBConverter
{
	public:
		// Construction and destruction.
		YUV420toRGBConverter(void) {_width = 0; _height = 0; _rotate = 0;}
		YUV420toRGBConverter(int width, int height) {_width = width; _height = height; _rotate = 0;}
		virtual ~YUV420toRGBConverter(void) {}

		// Interface.
		virtual void Convert(void* pY, void* pU, void* pV, void* pRgb) = 0;

		// Member interface.
		int	GetWidth(void)		{ return(_width); }
		int	GetHeight(void)		{ return(_height); }
		int	GetRotate(void)		{ return(_rotate); }

		void	SetDimensions(int width, int height)	{_width = width; _height = height;}
		void	SetRotate(int rotate)									{ _rotate = rotate;}

	protected:
		// Members.
		int	_width;
		int	_height;
		int	_rotate;

};//end YUV420toRGBConverter.


#endif	// _YUV420TORGBCONVERTER_H
